==> xmgfv1.9.1.tar.gz: xmgf/inc/GUI.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
void CreateARSizePal(Widget Parent);
void CreateColorPall(Widget Parent, int PopupType);
void CreateCommandPanel(Widget Parent, int PanelType, char *Message);
void CreateControlPopup(Widget Parent);
void CreateIconPopup(Widget Parent);
void CreateFillPal(Widget Parent);
void CreateLnPal(Widget Parent);
void CreatePtPal(Widget Parent);
void CreatePtSizePal(Widget Parent);
void CreateAxisSizePal(Widget Parent);
void CreateAnimSpeedPal(Widget Parent);
void CreateSetControlPopup(Widget Parent);
void CreateAnimPal(Widget Parent);
void GFControl(Widget Parent);
void GFDist_Widgets(Widget Parent);
void GFScale_Widgets(Widget Parent);
void GFTrans_Widgets(Widget Parent);
void GetSetNum(int *SetNum, int *LineNum);
void InitColorList(void);
void OriginClean(void);
void OriginSub(void);
int SearchNameList(char *SetName);
void SetNameLabel(char *buffer);
int SetXmgfMessage(char *buffer);
int ClearXmgfMessage(void);
void SetNumberLabel(int LineNum);
void UpdateList(void);
void UpdateSetName(int SetNum);
void UpdateXY(void);
void create_master_widgets(void);
void ChangeAngleLab(void);
void ChangeCurrentFile(char *currentFile);
void ChangeGammaLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangePhiLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangeThetaLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangeView(Widget w, caddr_t client_data, caddr_t call_data);
void CmdGammaCB(Widget w, caddr_t client_data, caddr_t call_data);
void CmdPhiCB(Widget w, caddr_t client_data, caddr_t call_data);
void CmdThetaCB(Widget w, caddr_t client_data, caddr_t call_data);
void CreateARSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void DoneCB(Widget w, Widget dialog, XmAnyCallbackStruct *call_data);
void ItemNumberCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillARSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillCommandCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillControlCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillIconCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillFillPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPtSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAxisSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimSpeedPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillSetControlCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectBGRDColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectHIGHColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectORIGColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectOUTColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SetCB(Widget w, caddr_t client_data, caddr_t call_data);
void XPolyAttrCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLnPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLnPal(void);
void KillPtPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPtPal(void);
void KillAxisPal(void);
void KillAxisPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimPal(void);
#else
void CreateARSizePal();
void CreateColorPall();
void CreateCommandPanel();
void CreateControlPopup();
void CreateIconPopup();
void CreateFillPal();
void CreateLnPal();
void CreatePtPal();
void CreatePtSizePal();
void CreateAxisSizePal();
void CreateSetControlPopup();
void GFControl();
void GFDist_Widgets();
void GFScale_Widgets();
void GFTrans_Widgets();
void GetSetNum();
void InitColorList();
void KillColorCB();
void KillCommandCB();
void OriginClean();
void OriginSub();
int SearchNameList();
void SelectBGRDColorCB();
void SelectColorCB();
void SelectHIGHColorCB();
void SelectORIGColorCB();
void SelectOUTColorCB();
void SetNameLabel();
void SetNumberLabel();
int SetXmgfMessage();
int ClearXmgfMessage();
void UpdateList();
void UpdateSetName();
void UpdateXY();
void create_master_widgets();
void ChangeAngleLab();
void ChangeCurrentFile();
void ChangeGammaLab();
void ChangePhiLab();
void ChangeThetaLab();
void ChangeView();
void CmdGammaCB();
void CmdPhiCB();
void CmdThetaCB();
void CreateARSizePalCB();
void DoneCB();
void ItemNumberCB();
void KillARSizePalCB();
void KillControlCB();
void KillIconCB();
void KillFillPalCB();
void KillPtPalCB();
void KillPtPal();
void KillPtSizePalCB();
void KillAxisPalCB();
void KillAxisPal();
void KillAxisSizePalCB();
void KillSetControlCB();
void SetCB();
void XPolyAttrCB();
void KillLnPalCB();
void KillLnPal();
void KillAnimPalCB();
void KillAnimPal();
void KillAnimSpeedPalCB();
void CreateAnimSpeedPal();
#endif

extern Widget AutoScale, AutoScaleVisible, ConButt, SetCButt, w_QuickQuit;
extern Widget ReDrawButt, BackCull, DrawAxis, SelColor, SortPolyButt;
extern Widget CntrlSetButt, Set2DButt, Del3DButt, QuitButt, Tool_Bar;
extern Widget Reset_Button, Rotate_Button, BURChetaLAB, PhiLAB, GammaLAB;
extern Widget TransformButtRC, TransformPre, Button_RCTop, submainpane;
extern Widget View_Pers, View_Orth, View_Ster, View_Radio, Button_RCBot;
extern Widget Distfr, DistRC, DistScal, ImgScale, CommandShell, ThRCfr;
extern Widget PhRCfr, GaRCfr, ThRC, PhRC, GaRC, TransformRC, TransformRes;
extern Widget ThetaValLAB, PhiValLAB, GammaValLAB, Transformfr, ItemButt;
extern Widget OriginButt, OriginColButt, HighLighButt, CommandShellDia;
extern Widget CommandShellDia, SetControlShellDia, ControlShellDia;
extern Widget ControlShell, SetControlShell, ARSizeShellDia, graphicspane;
extern Widget ThetaTog, PhiTog, GammaTog, AllScale, pieces,Orthdr;
extern Widget versionRC, versionFile, versionName, w_version, main_window;
extern Widget fr2, ScRC, w_Theta, w_Phi, w_Gamma, fr1, fr0, ViewManager;
extern Widget frameRC, fr2a, fr2b, ScRC1, OX, OY, OZ, toplevel, mainpane;
extern Widget ThetaLAB;
extern int TmpTheta, TmpPhi, TmpGamma;
extern Widget          IconShellDia,IconShell,IconCButt;
extern Widget     ArrIconPanel[ICONNUMBER];
extern Widget     ArrIconCanvas[ICONNUMBER];

==> xmgfv2.4.tar.gz: xmgf/inc/GUI.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#ifndef _NO_PROTO
void CreateARSizePal(Widget Parent);
void CreateColorPall(Widget Parent, int PopupType);
void CreateCommandPanel(Widget Parent, int PanelType, char *Message);
void CreateControlPopup(Widget Parent);
void CreateIconPopup(Widget Parent);
void CreateFillPal(Widget Parent);
void CreateLnPal(Widget Parent);
void CreatePtPal(Widget Parent);
void CreatePtSizePal(Widget Parent);
void CreateAxisSizePal(Widget Parent);
void CreateAnimSpeedPal(Widget Parent);
void CreateSetControlPopup(Widget Parent);
void CreateAnimPal(Widget Parent);
void GFControl(Widget Parent);
void GFDist_Widgets(Widget Parent);
void GFScale_Widgets(Widget Parent);
void GFTrans_Widgets(Widget Parent);
void GetSetNum(int *SetNum, int *LineNum);
void InitColorList(void);
void OriginClean(void);
void OriginSub(void);
int SearchNameList(char *SetName);
void SetNameLabel(char *buffer);
int SetXmgfMessage(char *buffer);
int ClearXmgfMessage(void);
void SetNumberLabel(int LineNum);
void UpdateList(void);
void UpdateSetName(int SetNum);
void UpdateXY(void);
void create_master_widgets(void);
void ChangeAngleLab(void);
void ChangeCurrentFile(char *currentFile);
void ChangeGammaLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangePhiLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangeThetaLab(Widget w, caddr_t client_data, caddr_t call_data);
void ChangeView(Widget w, caddr_t client_data, caddr_t call_data);
void CmdGammaCB(Widget w, caddr_t client_data, caddr_t call_data);
void CmdPhiCB(Widget w, caddr_t client_data, caddr_t call_data);
void CmdThetaCB(Widget w, caddr_t client_data, caddr_t call_data);
void CreateARSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void DoneCB(Widget w, Widget dialog, XmAnyCallbackStruct *call_data);
void ItemNumberCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillARSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillCommandCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillControlCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillIconCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillFillPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPtSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAxisSizePalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimSpeedPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillSetControlCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectBGRDColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectHIGHColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectORIGColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectOUTColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectHaloColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SelectStereoColorCB(Widget w, caddr_t client_data, caddr_t call_data);
void SetCB(Widget w, caddr_t client_data, caddr_t call_data);
void XPolyAttrCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLnPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillLnPal(void);
void KillPtPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillPtPal(void);
void KillAxisPal(void);
void KillAxisPalCB(Widget w, caddr_t client_data, caddr_t call_data);
void KillAnimPal(void);
void SetAnimFrameLabel(int FrameNumber,int  FramesOf);
Widget CreateHRowColumn(Widget parent,int columns);
Widget CreateVRowColumn(Widget parent,int columns);
Widget CreateSunkenMessageBox(char *Header,Widget parent);

#else
void CreateARSizePal();
void CreateColorPall();
void CreateCommandPanel();
void CreateControlPopup();
void CreateIconPopup();
void CreateFillPal();
void CreateLnPal();
void CreatePtPal();
void CreatePtSizePal();
void CreateAxisSizePal();
void CreateSetControlPopup();
void GFControl();
void GFDist_Widgets();
void GFScale_Widgets();
void GFTrans_Widgets();
void GetSetNum();
void InitColorList();
void KillColorCB();
void KillCommandCB();
void OriginClean();
void OriginSub();
int SearchNameList();
void SelectBGRDColorCB();
void SelectColorCB();
void SelectHIGHColorCB();
void SelectORIGColorCB();
void SelectOUTColorCB();
void SelectHaloColorCB();
void SelectStereoColorCB();
void SetNameLabel();
void SetNumberLabel();
int SetXmgfMessage();
int ClearXmgfMessage();
void UpdateList();
void UpdateSetName();
void UpdateXY();
void create_master_widgets();
void ChangeAngleLab();
void ChangeCurrentFile();
void ChangeGammaLab();
void ChangePhiLab();
void ChangeThetaLab();
void ChangeView();
void CmdGammaCB();
void CmdPhiCB();
void CmdThetaCB();
void CreateARSizePalCB();
void DoneCB();
void ItemNumberCB();
void KillARSizePalCB();
void KillControlCB();
void KillIconCB();
void KillFillPalCB();
void KillPtPalCB();
void KillPtPal();
void KillPtSizePalCB();
void KillAxisPalCB();
void KillAxisPal();
void KillAxisSizePalCB();
void KillSetControlCB();
void SetCB();
void XPolyAttrCB();
void KillLnPalCB();
void KillLnPal();
void KillAnimPalCB();
void KillAnimPal();
void KillAnimSpeedPalCB();
void CreateAnimSpeedPal();
void SetAnimFrameLabel();
Widget CreateHRowColumn();
Widget CreateVRowColumn();
Widget CreateSunkenMessageBox();
#endif

extern Widget AutoScale, AutoScaleVisible, ConButt, SetCButt, w_QuickQuit;
extern Widget ReDrawButt, BackCull, DrawAxis, SelColor, SortPolyButt;
extern Widget CntrlSetButt, Set2DButt, Del3DButt, QuitButt, Tool_Bar;
extern Widget Reset_Button, Rotate_Button, BURChetaLAB, PhiLAB, GammaLAB;
extern Widget TransformButtRC, TransformPre, Button_RCTop, submainpane;
extern Widget View_Pers, View_Orth, View_Ster, View_Radio, Button_RCBot;
extern Widget Distfr, DistRC, DistScal, ImgScale, CommandShell, ThRCfr;
extern Widget PhRCfr, GaRCfr, ThRC, PhRC, GaRC, TransformRC, TransformRes;
extern Widget ThetaValLAB, PhiValLAB, GammaValLAB, Transformfr, ItemButt;
extern Widget OriginButt, OriginColButt, HighLighButt, CommandShellDia;
extern Widget CommandShellDia, SetControlShellDia, ControlShellDia;
extern Widget ControlShell, SetControlShell, ARSizeShellDia, graphicspane;
extern Widget ThetaTog, PhiTog, GammaTog, AllScale, pieces,Orthdr;
extern Widget versionRC, versionFile, versionName, w_version, main_window;
extern Widget fr2, ScRC, w_Theta, w_Phi, w_Gamma, fr1, fr0, ViewManager;
extern Widget frameRC, fr2a, fr2b, ScRC1, OX, OY, OZ, toplevel, mainpane;
extern Widget ThetaLAB;
extern int TmpTheta, TmpPhi, TmpGamma;
extern Widget LeftRC,SubLeftRC,RCForm;
extern Widget IconShellDia,IconShell,IconCButt;
extern Widget ArrIconPanel[ICONNUMBER];
extern Widget ArrIconCanvas[ICONNUMBER];
extern int    DrawingAreaWidth;
extern int    DrawingAreaHeight;
extern Widget FrameInfo;
extern Widget Rightdr,Plandr,Sidedr,Frntdr;
